c      -*- Fortran -*-
c
c     Cavity Common Parameters / Common Variables
c


c     ----------------------
c       Common Parameters
c     ----------------------

ccc   input / output device 
c     data_fp = cav.dat
c     cnt_fp = cav.cnt
c     log_fp = cav.log
c     ps_fp = cav.ps
c     res_fp = cav.res
      parameter (l_data=11,l_cnt=12,l_log=13,l_meta=14,l_err=0)

ccc   Maximum Number Of Atoms in the DataFile
      parameter (maxatm=3000)

ccc   Maximum Number Of Atoms in one of the section of Cavity
      parameter (maxapl=500)

ccc   Maximum Number Of Bonds 
      parameter (maxbnd=400)

ccc   Maximum Number Of Bonds shown in the Figure
      parameter (maxplt=400)

ccc   Maximum Number Of Atoms in the Cavity
      parameter (maxexc=200)

ccc   Maximum Number Of Elements
      parameter (maxvdw=10)

ccc   Maximum Number Of Pens (Don't Edit)
      parameter (maxpen=4)

ccc   Automatic Range Extention Limit (from gravity center, in angstrome)
      parameter (fmaxar=15.0)

ccc   Automatic Range Extention  Step Width (in angstrome)
      parameter (fincst=1.0)

ccc   Initial Calculation Range Distance from atoms in cavity (in angstrome)
      parameter (cadd=1.5)

ccc   Degree to Radian Conversion Parameter (PI/180)
      parameter (dtor=3.14159265358979/180.0)

c     ------------------------
c         Common Variables
c     ------------------------

c     Title (in 40 characters)
      common /xtitle/title

c     Control Flags Group 1
c     iview  : View Angle
c     nint   : 
c     ivol   : Volume Calculation ? (do:1, don't:0)
c     iplot  : Plot Bonding ? (do:1, don't:0)
c     iprint :
c     icave  :
c     nplt   :
c     nbond  :
c     nexcl  :
      common /cnt1/iview,nint,ivol,IPLOT,IPRINT,ICAVE,
     $     NPLT,NBOND,NEXCL

c     Control Flags Group 2
c     scale  : Plot Scale  ( usually 1 )
c     radi   : Atom Radius ( usually 0 )
c     ipen(1),ipen(2),...  :  Pen Number ( usually 0,1,2,3 ... )
      common /CNT2/SCALE,RADI,IPEN(MaxPen)

c     Control Flags Group 3 (Atoms, Bonds, Atoms in Cavity)
c     iplt(1), iplt(2), ... : Atom Numbers shown in the Figure
c     [ips(1),ipe(1)],[ips(2),ipe(2)], ... : Atom Numbers of both sides
c                                            of Bonds shown in the figure
c     iexcl(1), iexcl(2), ... : Atom Numbers in Cavity
      common /CNT3/IPLT(MaxPlt),IPS(MaxBnd),IPE(MaxBnd),IEXCL(MaxExc)

c     Control Flags Group 4 (Van der Waals Radius + 1.2? Angstrome)
c     vdw(1),vdw(2), ... : Radius of Elements
      common /CNT4/VDW(MaxVDW)

c     Control Flags Group 5 (Calculation Range, Step in angstrome)
c     xmin, xmax, ymin, ymax, zmin, zmax : Calulation Range (used when nint=0)
c     divz   : Cavity/Volume Calculation Step
      common /CNT5/XMIN,XMAX,YMIN,YMAX,ZMIN,ZMAX,DIVZ

c     Temporary Variables  (Atoms on one of the section of the Cavity)
c     x(), y() : Location
c     r : radius of atom circle
c     r2 : R*R
c     name : Atom Name
c     inum : Atom Number
c     nplot :
c     ncrcl :
c     natom :
c     nex   :
c     zsec  : Z location of this plain
      common /PLN/X(MaxAPl),Y(MaxAPl),R(MaxAPl),R2(MaxAPl),NAME(MaxAPl),
     $     INUM(MaxAPl),nplot,ncrcl,NATOM,NEX,ZSEC,sx,sy,sr

c     Atom Data(Location, Color, Radius, ... )
c     natm  : 
c     itbl  :
c     xyz   : Location of Atoms
c     w     :
c     w2    :
c     icol  : Color Number of Atoms
      common /DAT/NATM(MaxAtm),ITBL(MaxAtm),XYZ(3,MaxAtm),
     $     W(MaxAtm),W2(MaxAtm),ICOL(MaxAtm)

c     Other Variables
c     sint, cost : sint(1)=sin(0 deg), ..., sint(n)=sin(n-1 deg)
c     kx, ky, kz : plot axis (from iview)
c     cmin, cmax : Plot Range
c     vmt : View Matrix
c     rvmt : View Matrix Inverse
c     org : Origin of Coordinate
c     lbuf : Line Buffer for Data Input
c     ierr : Error Flag
      common /etc/ sint(361),cost(361),kx,ky,kz,cmin(3),cmax(3),
     $     vmt(3,3),rvmt(3,3),org(3),lbuf,ierr,sxyz(3),sradi

c     Atoms Used to plot Cavity
c     iuse : Used Flag of Atom 
c     iusepl : Used Flag of Atom in the Plain
c     iusepn : 
      common /USE/IUSE(MaxAtm),IUSEPL(MaxAPl),IUsePN(MaxAPl)

c     Cavity Volume, Cavity Volume in One of The Section, ...
c     vol : total volume
c     plvol : volume in one section
      common /VOL/vol,plvol

      character title*40,natm*6,name*6,lbuf*80
